.. _basis:

Kiwisolver usage
================

.. include:: ../substitutions.sub

This section of the docs aims at getting you up and running with Kiwi. You will
in particular learn how to install Kiwi, create a system of constraints, solve,
update it etc... By the end of it you will know how to use the solver.

However if you are not familiar with Cassowary (or constraints solver in
general) it may not be enough to get you started using it in your project.
Hopefully the real world use cases described in :ref:`uses` will shed
more light on how to use it in real applications.

.. toctree::
   :maxdepth: 2

   installation.rst
   basic_systems.rst
   solver_internals.rst
